@@ -1,24 +1,26 @@
-# 
+#
 # This file is part of Audio-MPD-Common
-# 
+#
 # This software is copyright (c) 2007 by Jerome Quelin.
-# 
+#
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
-# 
+#
 use 5.008;
 use warnings;
 use strict;
 
 package Audio::MPD::Common::Types;
-our $VERSION = '1.100430';
+BEGIN {
+  $Audio::MPD::Common::Types::VERSION = '1.110550';
+}
 # ABSTRACT: types used in the distribution
 
 use Moose::Util::TypeConstraints;
 
 use Audio::MPD::Common::Time;
 
-enum 'State' => qw{ play stop pause };
+enum 'State' => [qw{ play stop pause }];
 
 coerce 'Audio::MPD::Common::Time'
     => from 'Str'
@@ -35,7 +37,7 @@ Audio::MPD::Common::Types - types used in the distribution
 
 =head1 VERSION
 
-version 1.100430
+version 1.110550
 
 =head1 DESCRIPTION
 
